@@ -1,5 +1,5 @@
 from autodiff_107.diff import numpy as np
-from autodiff_107.diff import Node
+from autodiff_107.diff.Node import Node
 
 def gradient_descent(f, x0, alpha, tol, max_iter):
     '''
